.. git-flow documentation master file, created by
   sphinx-quickstart on Tue Nov  2 13:23:54 2010.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to git-flow's documentation!
====================================

Contents:

.. toctree::
   :maxdepth: 2

   reference/index.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

